==> qpc_admob-0.0.2.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:qpc_admob/qpc_admob.dart';

void main() => runApp(MyApp());

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';

  @override
  void initState() {
    super.initState();
    initPlatformState();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    String platformVersion;
    // Platform messages may fail, so we use a try/catch PlatformException.
    try {
      platformVersion = await QpcAdmob.loadAd();
    } on PlatformException {
      platformVersion = 'Failed to get platform version.';
    }

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: FlatButton(onPressed: () async{
            try {
            _platformVersion = await QpcAdmob.loadAd();
            } on PlatformException {
            _platformVersion = 'Failed to get platform version.';
            }

          setState(() {
          _platformVersion = _platformVersion;
          });

          }, child: Text("播放广告$_platformVersion"),
        ),
      ),
    ));
  }
}

==> qpc_admob-0.0.6.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:qpc_admob/qpc_admob.dart';

void main() => runApp(MyApp());

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';

  @override
  void initState() {
    super.initState();
    initPlatformState();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    String platformVersion;
    // Platform messages may fail, so we use a try/catch PlatformException.
    try {
      //测试"5001121",正式"901121430"
      platformVersion = await QpcAdmob.instance.initialize(appId: "5001121").toString();
      RewardedVideoAd.instance.listener= (RewardedVideoAdEvent event, {String rewardType, int rewardAmount}) {
        print("RewardedVideoAd event $event");
        if (event == RewardedVideoAdEvent.rewarded) {
          setState(() {
            platformVersion = rewardType + rewardAmount.toString();
          });
        }
      };
    } on PlatformException {
      platformVersion = 'Failed to get platform version.';
    }

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: FlatButton(onPressed: () async{
            try {

              //测试adUnitId 901121430 ，正式：939140473
              RewardedVideoAd.instance.load(adUnitId: '901121430', userId: '12123333',targetingInfo: MobileAdTargetingInfo());
            } on PlatformException {
            _platformVersion = 'Failed to get platform version.';
            }

          setState(() {
          _platformVersion = _platformVersion;
          });

          }, child: Text("播放广告$_platformVersion"),
        ),
      ),
    ));
  }
}
